@@ -279,6 +279,7 @@ class NEUSetter:
                     'TaxNote',
                     'CRV',
                     'Name',
+                    'Note',
                     'Location',
                     'ALT_Barcode',
                     'DUP_Barcode',
@@ -292,11 +293,15 @@ class NEUSetter:
                     'Expiry',
                     'BestBy',
                     'AquisitionDate',
+                    'Tags',
                     ]
                 fields.extend(LOCATION_FIELDS)
+                fields=sorted(fields,key=str)
                 fct=len(fields)
+                t={i.name:str(i.type).lower() for i in Entry.__table__.columns}
                 for num,f in enumerate(fields):
-                    msg=f'{Fore.light_green}{num}/{Fore.light_yellow}{num+1} of {Fore.light_red}{fct} -> {Fore.turquoise_4}{f}{Style.reset}'
+
+                    msg=std_colorize(f,num,fct)+f"{Fore.red}[{Fore.cyan}{t[f]}{Fore.red}]{Fore.light_yellow}!{Style.reset}"
                     print(msg)
                 fnames=[]
                 which=Prompt.__init2__(None,func=FormBuilderMkText,ptext=f"which {Fore.light_green}index{Fore.light_red}({Fore.light_green}es{Fore.light_red}){Fore.light_yellow}?: ",helpText=f"which {Fore.light_green}index{Fore.light_red}({Fore.light_green}es{Fore.light_red}){Fore.light_yellow}, use comma to separate multiple fields{Style.reset}",data="list")
@@ -359,9 +364,15 @@ class NEUSetter:
                     for fname in fnames:
                         column=getattr(Entry,fname)
                         oldprice=getattr(selected,'Price')
-                        newValue=Prompt.__init2__(None,func=FormBuilderMkText,ptext=f"[{Fore.medium_violet_red}old{Fore.light_yellow}] {Fore.light_magenta}{fname} = {Fore.light_red}{getattr(selected,fname)}{Fore.orange_red_1} to: {Style.reset}",helpText="new value",data=str(column.type))
+                        if fname.lower()  in ['tags','tag']:
+                            TYPE="list"
+                        else:
+                            TYPE=str(column.type)
+                        newValue=Prompt.__init2__(None,func=FormBuilderMkText,ptext=f"[{Fore.medium_violet_red}old{Fore.light_yellow}] {Fore.light_magenta}{fname} = {Fore.light_red}{getattr(selected,fname)}{Fore.orange_red_1} to: {Style.reset}",helpText="new value",data=TYPE)
                         if newValue in [None,'d']:
                             continue
+                        if fname.lower() in ['tags','tag']:
+                            newValue=json.dumps(newValue)
                         if fname.lower() == 'tax':
                             if not tax_adjusted:
                                 setattr(selected,fname,newValue)
